function [Edata EL] = predict_Rhizoglyphus_robini(par, data, tL)
% par: (19)-vector with parameters (see below)
% data:(r_d,1)-matrix with zero-variate data (not all elements are used)
% tL: (r_L,1)-matrix with time since birth, length
% Edata:(r_d,1)-matrix with predicted values for data(:,2)
% EL:(r_L,1)-matrix with predicted values for tL(:,2)

  global dwm % import values set in mydata_Pristis_pectinata

%% unpack par
  T_ref  = par(1); % K, temp for which rate pars are given 
  T_A    = par(2); % K, Arrhenius temp
  f      = par(3); % -, scaled functional response
  z      = par(4); % -, zoom factor for female
  del_M  = par(5); % -, shape coefficient to convert vol-length to physical length
  F_m    = par(6); % l/d.cm^2, {F_m}, max spec searching rate
  kap_X  = par(7); % -, digestion efficiency of food to reserve
  v      = par(8); % cm/d, energy conductance
  kap    = par(9);% -, allocation fraction to soma = growth + somatic maintenance
  kap_R  = par(10);% -, reproduction efficiency
  p_M    = par(11);% J/d.cm^3, [p_M], vol-specific somatic maintenance
  p_T    = par(12);% J/d.cm^2, {p_T}, surface-specific som maintenance
  k_J    = par(13);% 1/d, maturity maint rate coefficient
  E_G    = par(14);% J/cm^3, [E_G], spec cost for structure
  E_Hb   = par(15);% J, E_H^b, maturity at birth
  E_Hp   = par(16);% J, E_H^p, maturity at puberty
  h_a    = par(17);% 1/d^2, Weibull aging acceleration
  s_G    = par(18);% -, Gompertz stress coefficient
  f_tL   = par(19);% -, functional response for tL-data

  d_V = dwm(2,1);  d_E = dwm(3,1); % g/cm^3, specific densities for structure and reserve
  w_V = dwm(2,2);  w_E = dwm(3,2); % g/mol,  molecular weights for structure and reserve
  mu_V = dwm(2,3); mu_E = dwm(3,3);% J/mol,  chemical potentials for structure and reserve

  % Selected copy-paste from parscomp & statistics
  p_Am = z * p_M/ kap;             % J/d.cm^2, {p_Am} max spec assimilation flux for female
  J_E_Am = p_Am/ mu_E;             % mol/d.cm^2, {J_EAm}, max surface-spec assimilation flux for female
  k_M = p_M/ E_G;                  % 1/d, somatic maintenance rate coefficient
  k = k_J/ k_M;                    % -, maintenance ratio
  % p_Xm = p_Am/ kap_X;            % J/d.cm^2, max spec feeding power

  M_V = d_V/ w_V;                  % mol/cm^3, [M_V], volume-specific mass of structure
  kap_G = M_V * mu_V/ E_G;         % -, growth efficiency
  y_V_E = mu_E * M_V/ E_G;         % mol/mol, yield of structure on reserve
  y_E_V = 1/ y_V_E;                % mol/mol, yield of reserve on structure

  E_m = p_Am/ v;                   % J/cm^3, [E_m] reserve capacity for female
  m_Em = y_E_V * E_m/ E_G;         % mol/mol, reserve capacity 
  g = E_G/ kap/ E_m;               % -, energy investment ratio for female
  w = m_Em * w_E/ w_V;             % -, contribution of reserve to weight

  L_m = v/ k_M/ g;                 % cm, maximum structural length
  L_T = p_T/ p_M;                  % cm, heating length (also applies to osmotic work)
  l_T = L_T/ L_m;                  % -, scaled heating length

  % maturity at birth
  M_Hb = E_Hb/ mu_E;               % mol, maturity at birth  
  U_Hb = M_Hb/ J_E_Am;             % cm^2 d, scaled maturity at birth
  u_Hb = U_Hb * g^2 * k_M^3/ v^2;  % -, scaled maturity at birth
  V_Hb = U_Hb/ (1 - kap);          % cm^2 d, scaled maturity at birth
  v_Hb = V_Hb * g^2 * k_M^3/ v^2;  % -, scaled maturity at birth
  % maturity at puberty
  M_Hp = E_Hp/ mu_E;               % mol, maturity at puberty
  U_Hp = M_Hp/ J_E_Am;             % cm^2 d, scaled maturity at puberty 
  u_Hp = U_Hp * g^2 * k_M^3/ v^2;  % -, scaled maturity at puberty  
  V_Hp = U_Hp/ (1 - kap);          % cm^2 d, scaled maturity at puberty
  v_Hp = V_Hp * g^2 * k_M^3/ v^2;  % -, scaled maturity at puberty

  %% zero-variate data

  % temperature the same for all data
  TC = tempcorr(data(1,1), T_ref, T_A);   % -, Temperature Correction factor for a_b; ONLY WORK WITH T_A

  % birth
  pars_lb = [g; k; v_Hb];        % compose parameter vector
  [t_b, l_b info] = get_tb(pars_lb); % -, scaled length and age at birth at f
  if info ~= 1 % numerical procedure failed
    fprintf('warning: invalid parameter value combination for get_lb \n')
  end
  L_b = L_m * l_b;     % cm, structural length at birth at f
  Lw_b = L_b/ del_M;   % cm, physical length at birth at f
  %Ww_b = L_b^3 * (1 + f * w); % g, wet weight at birth at f
  aT_b = t_b/ k_M/ TC; % d, age at birth at f and T

  % puberty and ultimate size
  pars_tp = [g; k; l_T; v_Hb; v_Hp]; % compose parameter vector
  [t_p t_b l_p l_b info] = get_tp(pars_tp, f, l_b); % -, scaled length at birth at f
  if info ~= 1 % numerical procedure failed
      fprintf('warning: invalid parameter value combination for get_tp \n')
  end
  L_p = L_m * l_p;              % cm, structural length at puberty at f
  Lw_p = L_p/ del_M;            % cm, physical length at puberty at f
  %Ww_p = L_p^3 * (1 + f * w);   % g, wet weight at puberty 
  aT_p = t_p/ k_M/ TC;          % d, age at puberty at f and T

  % ultimate size
  l_i = f - l_T;                % -, scaled ultimate length at f
  L_i = L_m * l_i;              % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;            % cm, ultimate physical length at f
  Ww_i = L_i^3 * (1 + f * w);   % g, ultimate wet weight 
  
  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hp]; % compose parameter vector at T
  RT_i = TC * reprod_rate(L_i, f, pars_R); % #/d, ultimate reproduction rate at T

  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];     % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);         % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC;                     % d, mean life span at T

  % pack output for zero-variate data
  Edata = [aT_b; aT_p; aT_m; Lw_b; Lw_p; Lw_i; Ww_i; RT_i;  % real data, T-corrected
           v; kap; kap_R; p_M; p_T; k_J; kap_G];      % pseudo data at T_ref

%% uni-variate data
  f = f_tL;
  [t_b, l_b info] = get_tb(pars_lb,f); % -, scaled length and age at birth at f
  Lw_b = L_m * l_b/ del_M; Lw_i = L_m * f/ del_M;
  ir_B = 3/ k_M + 3 * f * L_m/ v; r_B = 1/ ir_B;     % d, 1/von Bert growth rate
  EL = Lw_i - (Lw_i - Lw_b) * exp( - TC * r_B * tL(:,1)); % cm, expected length at time

  