function [ImaxQs,PopQsAll] = PredictImax(Imax_min,Imax_max,step, timesteps)

% Please cite:

% To create figure 5:
% [ImaxQs, PopQsAll] = PredictImax(0.05, 0.4, 56, 2000);

% input: 
% Imax_min: minimum max ingestion rate
% Imax_max: maximum max ingestion rate
% step: step size between Imax_min and Imax_max
% timesteps: length of one simulation run

% IPM parameters
Lmin = 150/1000; % minimum body length in mm (used to define limits of matrix approximation)
Lb = 167/1000; % length at birth in mm 
Lm_default = 1008/1000; % maximum body length in mm
E_Ystdev=0.3; % sigma(Y)
MatrixSize = 200;


% DEB parameters 
kappa = 0.082; % fraction energy allocation to respiration (as opposed to reproduction)
mu = 0.03; % mortality rate
beta = 151; % to calculate von Bertalanffy growth rate r_b
alpha = -137.8; % to calculate von Bertalanffy growth rate r_b
Rm_default = 32; % maximum reproduction rate at L_m
d_Lp = 0.539; % proportionality constant for Lp

% Resource parameters
Xmax = 4; % max resource abundance in absence of consumers
rho = 0.1; % resource renewal rate; default value 0.1 
K = 5; % half-saturation constant; default value 5
Imax = linspace(Imax_min,Imax_max,step);
Imax_default = 0.1;

% starting values for first run; following runs use end values
% of previous run as starting values.
X = Xmax;

% starting values for first run; following run uses end values
% of previous run as starting values.
X = Xmax;
time = 1;

for i = 1:length(Imax), i/length(Imax)

        % reset time
        time = 1;
        % reset resource and consumer density, and MatrixSize to keep same bin sizes. 
        % Default bin size is 0.0047 with 200 bins in default situation.
        Lm = Imax(i)/Imax_default*Lm_default;
        Rm = (Imax(i)/Imax_default).^3*Rm_default
        L = Lmin; U = 1.1*Lm; MatrixSize = round((U - L)/0.0047);
        w0 = 0.01*ones(MatrixSize, 1);
        w_dead = zeros(MatrixSize, 1);
        ntv = w0;
        
            while time < timesteps

            E_Y = X/(K+X) ; % functional response

            % calculate IPM and pop quantities
                if sum(ntv)>0, % only calculate kernel if consumer population is alive
    
                % update DEB pars          
                Linf = E_Y*Lm;
                Lp = max(0.314,0.539*Linf); % minimum size for reproduction of 0.314 mm
                rb = 1/(beta + alpha*Linf); % von Bertellanfy growth rate
            
                % kernel                
                [S, R, G, D, meshpts] = BigMatrixShrink(MatrixSize,Lmin,Lm,Lp,Rm,Lm,E_Y,E_Ystdev,rb,kappa,Lb,mu);
                kernelDEB = G*S + D*R; 
                % lambda and ssd
                [W,d] = eig(kernelDEB); lambda1 = diag(d); imax = find(lambda1==max(lambda1)); 
                lambda = max(lambda1(imax)); % population growth rate
                w1=W(:,imax); ssd = w1/sum(w1); ssd = ssd'; % stable stage distribution
                % LRS 
                [m,p]=size(kernelDEB); TS = G*S; Fmat = D*R; 
                R0mat = Fmat*inv((eye(m)-TS)); meanLRS = max(eig(R0mat)); 
                % generation time
                GT = log(meanLRS)/log(lambda);
                %  density of juvs and adults:
                index_adults =  meshpts>=Lp; adultdens = sum(ntv.*index_adults');
                index_juvs =  meshpts<Lp; juvdens = sum(ntv.*index_juvs');                
                else  disp('C dead'); ntv = w_dead'; lambda = NaN; meanLRS = NaN; GT = NaN; Linf = NaN; Lp = NaN; adultdens = NaN; juvdens = NaN; 
                end
                
            PopQstemp = [time,E_Y,sum(ntv),Linf,Lp,adultdens, juvdens, lambda,meanLRS,GT,X];
            PopQs(time,:) = PopQstemp;
                              
            % resource growth
            X_growth = (1-rho)*X + rho*Xmax;
            % resource consumption
            X_consumption = Imax(i)*E_Y*sum(ntv'.*meshpts.^2);
            
            % update population, resource density, time step 
            X = X_growth - X_consumption; 
            X = max(X,0); % to remove negative values
                               
            ntv = kernelDEB*ntv;
            time = time + 1;
                     
            end
        PopQsAll(:,:,i) = PopQs;
        ImaxQs(i,:) = [Imax(i),min(PopQs(0.7*timesteps:end-1,2)),max(PopQs(0.7*timesteps:end-1,2)),PopQs(end-1,2)-PopQs(end-30,2),... % E(Y)
                min(PopQs(0.7*timesteps:end-1,6)),max(PopQs(0.7*timesteps:end-1,6)),PopQs(end-1,6)-PopQs(end-30,6),... % adults
                min(PopQs(0.7*timesteps:end-1,7)),max(PopQs(0.7*timesteps:end-1,7)),PopQs(end-1,7)-PopQs(end-30,7),... % juveniles
                min(PopQs(0.7*timesteps:end-1,11)),max(PopQs(0.7*timesteps:end-1,11)),PopQs(end-1,11)-PopQs(end-30,11),...% resource
            mean(PopQs(0.7*timesteps:end-1,6)), mean(PopQs(0.7*timesteps:end-1,7)), mean(PopQs(0.7*timesteps:end-1,11))] ; % mean adult, juv, resource
        save PopQsAll PopQsAll; save ImaxQs ImaxQs
end

%% Figure
load ImaxQs
load PopQsAll
Imax=ImaxQs(1:end,1);

resource = squeeze(PopQsAll(end,11,1:end));
E_Y = squeeze(PopQsAll(end,2,1:end));
juvs = squeeze(PopQsAll(end,7,1:end)); 
adults = squeeze(PopQsAll(end,6,1:end)); 

figure
subplot(4,2,1); plot(Imax,resource,'k-','LineWidth',2); box off;  
        ylabel('Resource density','FontSize',14); xlabel('Imax'); 
        subplot(4,2,3); plot(Imax,E_Y,'k-','LineWidth',2); box off; 
        ylabel('Feeding level','FontSize',14); xlabel('Imax');  
        subplot(4,2,5); plot(Imax,juvs,'k','LineWidth',2); box off
        ylabel('Density','FontSize',14);  xlabel('Imax');  set(gca,'FontSize',12); 
        subplot(4,2,7); plot(Imax,adults,'k','LineWidth',2); box off
        ylabel('Density','FontSize',14);  xlabel('Imax');  set(gca,'FontSize',12);     
