function [RhoQs,PopQsAll] = PredictRho(Rho_min,Rho_max,step, timesteps)

% Please cite:

% To create figure 4:
% [RhoQs,PopQsAll] = PredictRho(0.05, 1, 96, 2000);

% input: 
% Rho_min: minimum resource replenishment rate
% Rho_max: maximum fresource replenishment rate
% step: step size between Rho_min and Rho_max
% timesteps: length of one simulation run

% IPM parameters
Lmin = 150/1000; % minimum body length in mm (used to define limits of matrix approximation)
Lb = 167/1000; % length at birth in mm 
Lm = 1008/1000; % maximum body length in mm
E_Ystdev=0.3; % sigma(Y)
MatrixSize = 200;
rho = linspace(Rho_min,Rho_max,step);

% DEB parameters 
kappa = 0.082; % fraction energy allocation to respiration (as opposed to reproduction)
mu = 0.03; % mortality rate
beta = 151; % to calculate von Bertalanffy growth rate r_b
alpha = -137.8; % to calculate von Bertalanffy growth rate r_b
Rm = 32; % maximum reproduction rate at L_m
d_Lp = 0.539; % proportionality constant for Lp

% Resource parameters
Xmax = 4; % max resource abundance in absence of consumers
Imax = 0.1; % max ingestion rate; default value 0.1 
K = 5; % half-saturation constant; default value 5

% starting values for first run; following runs use end values
% of previous run as starting values.
X = Xmax;
w0 = 0.01*ones(MatrixSize, 1); % start population vector
ntv = w0;

for i = 1:length(rho), i/length(rho)
            
        % reset time
        time = 1;
        % reset resource and consumer density
        if sum(ntv)<=0, ntv=w0; else ntv=ntv; end % if consumers went extinct start with initial consumer size distribution
            
            while time < timesteps
            E_Y = X/(K+X) ; % functional response

                % calculate kernel and population biology quantities
                if sum(ntv)>0, % only calculate kernel if C is alive

                 % update DEB pars          
                Linf = E_Y*Lm;
                Lp = max(0.314,d_Lp*Linf); % minimum size for reproduction of 0.314 mm
                rb = 1/(beta + alpha*Linf); % von Bertellanfy growth rate
            
                % kernel
                [S, R, G, D, meshpts] = BigMatrixShrink(MatrixSize,Lmin,Lm,Lp,Rm,Lm,E_Y,E_Ystdev,rb,kappa,Lb,mu);
                kernelDEB = G*S + D*R; 
                % lambda and ssd
                [W,d] = eig(kernelDEB); lambda1 = diag(d); imax = find(lambda1==max(lambda1)); 
                lambda = max(lambda1(imax)); w1=W(:,imax); % lambda
                ssd = w1/sum(w1); ssd = ssd'; % stable stage distribution
                % LRS 
                [m,p]=size(kernelDEB); TS = G*S; Fmat = D*R; 
                R0mat = Fmat*inv((eye(m)-TS)); meanLRS = max(eig(R0mat)); 
                % generation time
                GT = log(meanLRS)/log(lambda);
                %  density of juvs and adults
                index_adults =  meshpts>=Lp; adultdens = sum(ntv.*index_adults');
                index_juvs =  meshpts<Lp; juvdens = sum(ntv.*index_juvs');
            
                else  disp('C dead'); ntv = w_dead'; lambda = 0; meanLRS = 0; GT = 0; Linf = NaN; Lp = NaN; adultdens = NaN; juvdens = NaN; 
                end
                
            popstructure(:,time) = ntv; 
            PopQstemp = [time,E_Y,sum(ntv),Linf,Lp,adultdens, juvdens, lambda,meanLRS,GT,X];
            PopQs(time,:) = PopQstemp;
                              
            % resource growth
            X_growth =(1-rho(i))*X + rho(i)*Xmax;
            
            % resource consumption
            X_consumption = Imax*E_Y*sum(ntv'.*meshpts.^2);
            
            % update population, resource density, time step 
            X = X_growth - X_consumption; 
            X = max(X,0); % to remove negative values
            
            ntv = kernelDEB*ntv;
            time = time + 1;
                     
            end
        PopQsAll(:,:,i) = PopQs;
        RhoQs(i,:) = [rho(i),min(PopQs(0.7*timesteps:end-1,2)),max(PopQs(0.7*timesteps:end-1,2)),PopQs(end-1,2)-PopQs(end-30,2),... % E_Y
                min(PopQs(0.7*timesteps:end-1,6)),max(PopQs(0.7*timesteps:end-1,6)),PopQs(end-1,6)-PopQs(end-30,6),... % adults
                min(PopQs(0.7*timesteps:end-1,7)),max(PopQs(0.7*timesteps:end-1,7)),PopQs(end-1,7)-PopQs(end-30,7),...% juveniles
                min(PopQs(0.7*timesteps:end-1,11)),max(PopQs(0.7*timesteps:end-1,11)),PopQs(end-1,11)-PopQs(end-30,11),...% resource
                mean(PopQs(0.7*timesteps:end-1,6)), mean(PopQs(0.7*timesteps:end-1,7)), mean(PopQs(0.7*timesteps:end-1,11))] ; % mean adult, juv, resource
        save PopQsAll PopQsAll; save RhoQs RhoQs
end


%% Figure 
load RhoQs
load PopQsAll
Rho=RhoQs(1:end,1);

resource = squeeze(PopQsAll(end,11,1:end));
E_Y = squeeze(PopQsAll(end,2,1:end));
juvs = squeeze(PopQsAll(end,7,1:end)); 
adults = squeeze(PopQsAll(end,6,1:end));

figure
subplot(4,2,1); plot(Rho,resource,'k-','LineWidth',2); box off;  
        ylabel('Resource density','FontSize',14); xlabel('Rho'); 
        subplot(4,2,3); plot(Rho,E_Y,'k-','LineWidth',2); box off; 
        ylabel('Feeding level','FontSize',14); xlabel('Rho');  
        subplot(4,2,5); plot(Rho,juvs,'k','LineWidth',2); box off
        ylabel('Density','FontSize',14);  xlabel('Rho');  set(gca,'FontSize',12); 
        subplot(4,2,7); plot(Rho,adults,'k','LineWidth',2); box off
        ylabel('Density','FontSize',14);  xlabel('Rho');  set(gca,'FontSize',12); 